==> jc-1.4.0.tar.gz: java/awt/DefaultKeyboardFocusManager__24EventDelayRequest.h <==
// class java.awt.DefaultKeyboardFocusManager$EventDelayRequest

// class file dependencies
// @dep_class eaf5949488b88e90 java_awt_DefaultKeyboardFocusManager__24EventDelayRequest
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest_H_
#define _JC_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_DefaultKeyboardFocusManager$object;
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedList$object;

// Typedefs
typedef struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_refs	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_refs;
typedef struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_nonrefs	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_nonrefs;
typedef struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$refs	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$refs;
typedef struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$nonrefs	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$nonrefs;
typedef struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object;

typedef const struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vmethods	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vmethods;
typedef const struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtable	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtable;
typedef const struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtype	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtype;

// Constructors
extern void _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$_init$498d64003c9aba09(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_awt_DefaultKeyboardFocusManager$object *, jlong, struct _jc_java_awt_Component$object *);

// Virtual methods
extern jint _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_lang_Object$object *);
extern void _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$discardEvents$bd54b9e14e283050(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *);
extern void _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$dispatchEvents$cf5a30cc213e92f8(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *);
extern void _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$enqueueEvent$be05eb147071cb2c(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_awt_event_KeyEvent$object *);
extern jboolean _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_lang_Object$object *);
extern void _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$compareTo$84fc6fc4a23c98a3;
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$discardEvents$bd54b9e14e283050;
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$dispatchEvents$cf5a30cc213e92f8;
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$enqueueEvent$be05eb147071cb2c;
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_lang_Object$object *);
	void	(*discardEvents$bd54b9e14e283050)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *);
	void	(*dispatchEvents$cf5a30cc213e92f8)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *);
	void	(*enqueueEvent$be05eb147071cb2c)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_awt_event_KeyEvent$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_lang_Object$object *);
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *);
};

// Vtable
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vmethods	java_awt_DefaultKeyboardFocusManager__24EventDelayRequest;
};

// Vtype
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtype {
	_jc_type			type;
	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_refs {
	struct _jc_java_util_LinkedList$object	*enqueuedKeyEvents;
	struct _jc_java_awt_Component$object	*focusedComp;
	struct _jc_java_awt_DefaultKeyboardFocusManager$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$refs {
    _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_refs	java_awt_DefaultKeyboardFocusManager__24EventDelayRequest;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_nonrefs {
	jlong	timestamp;
};

// Non-reference instance fields (object)
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_nonrefs	java_awt_DefaultKeyboardFocusManager__24EventDelayRequest;
};

// Object instance structure
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object {
	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtype	*vtype;
	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtype _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_DefaultKeyboardFocusManager__24EventDelayRequest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$class_object;

#endif	/* _JC_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest_H_ */

==> jc-1.4.6.tar.gz: java/awt/DefaultKeyboardFocusManager__24EventDelayRequest.h <==
// class java.awt.DefaultKeyboardFocusManager$EventDelayRequest

// class file dependencies
// @dep_class eaf5949488b88e90 java_awt_DefaultKeyboardFocusManager__24EventDelayRequest
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest_H_
#define _JC_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_DefaultKeyboardFocusManager$object;
struct _jc_java_awt_event_KeyEvent$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedList$object;

// Typedefs
typedef struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_refs	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_refs;
typedef struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_nonrefs	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_nonrefs;
typedef struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$refs	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$refs;
typedef struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$nonrefs	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$nonrefs;
typedef struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object;

typedef const struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vmethods	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vmethods;
typedef const struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtable	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtable;
typedef const struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtype	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtype;

// Constructors
extern void _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$_init$498d64003c9aba09(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_awt_DefaultKeyboardFocusManager$object *, jlong, struct _jc_java_awt_Component$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$compareTo$84fc6fc4a23c98a3(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$discardEvents$bd54b9e14e283050(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$dispatchEvents$cf5a30cc213e92f8(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$enqueueEvent$be05eb147071cb2c(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method$this$adc93fb6bf4cbffa(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$compareTo$84fc6fc4a23c98a3;
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$discardEvents$bd54b9e14e283050;
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$dispatchEvents$cf5a30cc213e92f8;
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$enqueueEvent$be05eb147071cb2c;
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$method_info$this$adc93fb6bf4cbffa;

// Virtual methods structure
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vmethods {
	jint	(*compareTo$84fc6fc4a23c98a3)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*discardEvents$bd54b9e14e283050)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *) _JC_JCNI_ATTR;
	void	(*dispatchEvents$cf5a30cc213e92f8)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *) _JC_JCNI_ATTR;
	void	(*enqueueEvent$be05eb147071cb2c)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_awt_event_KeyEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	void	(*this$adc93fb6bf4cbffa)(_jc_env *, struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vmethods	java_awt_DefaultKeyboardFocusManager__24EventDelayRequest;
};

// Vtype
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtype {
	_jc_type			type;
	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_refs {
	struct _jc_java_util_LinkedList$object	*enqueuedKeyEvents;
	struct _jc_java_awt_Component$object	*focusedComp;
	struct _jc_java_awt_DefaultKeyboardFocusManager$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$refs {
    _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_refs	java_awt_DefaultKeyboardFocusManager__24EventDelayRequest;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_nonrefs {
	jlong	timestamp;
};

// Non-reference instance fields (object)
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$sub_nonrefs	java_awt_DefaultKeyboardFocusManager__24EventDelayRequest;
};

// Object instance structure
struct _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$object {
	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtype	*vtype;
	_jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$vtype _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_DefaultKeyboardFocusManager__24EventDelayRequest, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest$class_object;

#endif	/* _JC_java_awt_DefaultKeyboardFocusManager__24EventDelayRequest_H_ */
